@@ -26,7 +26,12 @@ qx.Class.define("callbackery.ui.Busy", {
     type : "singleton",
 
     construct : function() {
-        this.base(arguments,null,"callbackery/spinner.gif");
+        var img = 'callbackery/spinner.gif';
+        var cfg = callbackery.data.Config.getInstance().getBaseConfig();
+        if (cfg.spinner){
+            img = cfg.spinner;
+        }
+        this.base(arguments,null,img);
         this.set({
             center : true,
             show: 'both',
